OiRA

Help

1. Подготовка
2. Включване
3. Определяне + Оценяване
4. План за действие
5. Доклад
6. Статус 0%

# Адаптирате оценката на риска към Вашата организация

За да се адаптира оценката на риска към Вашата организация, от Вас може да бъде поискано да:

- изберете или пропуснете ситуация(и), имащи или нямащи отношение към Вашата бизнес дейност и отметнете кутийката(ите), ако е уместно
- избройте множество бизнес звена, или клонове, или магазини, и т.н. Тези свързани рискове ще бъдат повторени за всяко име, което сте въвели.

## Commercial manned guarding

Does your organisation provide commercial manned guarding? Yes No
Do you offer this service in multiple locations? Yes No
Please enter a name for the location you would like to assess. Please enter the name for each location you would like to assess.

## Mobile partrolling/intervention after alarm

Does your organisation provide mobile patrolling / intervention after alarm? Yes No
Do you offer this service in multiple locations? Yes No
Please enter a name for the location you would like to assess. Please enter the name for each location you would like to assess.

## Event security

Does your organisation provide event security? Yes No
Do you offer this service in multiple locations? Yes No
Please enter a name for the location you would like to assess. Please enter the name for each location you would like to assess.

Scroll to top
Back

## profiling.html

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More